summaryrefslogtreecommitdiff
path: root/mysql-test
diff options
context:
space:
mode:
authorunknown <mkindahl@dl145h.mysql.com>2008-02-04 07:15:14 +0100
committerunknown <mkindahl@dl145h.mysql.com>2008-02-04 07:15:14 +0100
commit2bccc0e6005f3f2e6c45773444d9d6f65c741241 (patch)
tree424ce7328f1504f753709586a3f2719661b98307 /mysql-test
parent0780f0bf98f2232c744800b0466376ee39cceb65 (diff)
downloadmariadb-git-2bccc0e6005f3f2e6c45773444d9d6f65c741241.tar.gz
Masking out some more errors and warnings that are benign.
mysql-test/include/delete_anonymous_users.inc: Disabling warnings. mysql-test/lib/mtr_report.pl: Masking out benign errors and warnings from var/log/warnings file.
Diffstat (limited to 'mysql-test')
-rw-r--r--mysql-test/include/delete_anonymous_users.inc2
-rw-r--r--mysql-test/lib/mtr_report.pl13
2 files changed, 12 insertions, 3 deletions
diff --git a/mysql-test/include/delete_anonymous_users.inc b/mysql-test/include/delete_anonymous_users.inc
index 9f642223748..704e74ae4a3 100644
--- a/mysql-test/include/delete_anonymous_users.inc
+++ b/mysql-test/include/delete_anonymous_users.inc
@@ -1,5 +1,7 @@
# Remove anonymous users added by add_anonymous_users.inc
+disable_warnings;
disable_query_log;
DELETE FROM mysql.user where host='localhost' and user='';
FLUSH PRIVILEGES;
enable_query_log;
+enable_warnings;
diff --git a/mysql-test/lib/mtr_report.pl b/mysql-test/lib/mtr_report.pl
index ad7142489fe..37863ce4187 100644
--- a/mysql-test/lib/mtr_report.pl
+++ b/mysql-test/lib/mtr_report.pl
@@ -375,9 +375,16 @@ sub mtr_report_stats ($) {
/Slave: Cannot add or update a child row: a foreign key constraint fails .* Error_code: 1452/
)) or
- # rpl_skip_error produce an error which is skipped (slave does not stop)
- ($testname eq 'rpl.rpl_skip_error' and
- /Failed to write to mysql\.general_log/)
+ # rpl_skip_error and binlog_killed_simulate produce an error which is skipped (slave does not stop)
+ (($testname eq 'rpl.rpl_skip_error' or
+ $testname eq 'binlog.binlog_killed_simulate') and
+ (/Failed to write to mysql\.general_log/
+ )) or
+
+ # rpl_temporary has an error on slave that can be ignored
+ ($testname eq 'rpl.rpl_temporary' and
+ (/Slave: Can\'t find record in \'user\' Error_code: 1032/
+ ))
)
{
next; # Skip these lines